pub static VERBS: &[&str] = &[
    "suspended",
    "labelled",
    "counted",
    "parted",
    "carried",
    "flaps",
    "relys",
    "floated",
    "points",
    "recorded",
    "misss",
    "walked",
    "stops",
    "squeaked",
    "crawled",
    "strengthens",
    "suspends",
    "pulled",
    "prints",
    "planted",
    "drys",
    "flooded",
    "blinds",
    "pointed",
    "fixs",
    "licenses",
    "stripped",
    "squashed",
    "injures",
    "heads",
    "meddles",
    "launched",
    "serves",
    "emptied",
    "copied",
    "wiped",
    "receives",
    "refused",
    "relaxs",
    "coloured",
    "pours",
    "opened",
    "caused",
    "instructed",
    "failed",
    "smiled",
    "filled",
    "collected",
    "arranged",
    "healed",
    "sucks",
    "amuses",
    "blessed",
    "trys",
    "surrounds",
    "bored",
    "gazes",
    "waved",
    "founded",
    "winks",
    "shrugged",
    "filed",
    "lists",
    "crys",
    "punished",
    "attends",
    "bolted",
    "bubbles",
    "launchs",
    "hops",
    "attracts",
    "framed",
    "employs",
    "colours",
    "untidys",
    "supplys",
    "helped",
    "murdered",
    "attended",
    "dares",
    "doubts",
    "nailed",
    "ends",
    "overflows",
    "locked",
    "interrupted",
    "flashs",
    "breathed",
    "dammed",
    "raised",
    "boasts",
    "requests",
    "zips",
    "concentrated",
    "grins",
    "pops",
    "enjoys",
    "questioned",
    "happens",
    "hugs",
    "identified",
    "extends",
    "marks",
    "lightened",
    "tipped",
    "objected",
    "reproduces",
    "drowned",
    "sprouts",
    "yawned",
    "possesss",
    "thanks",
    "sneezes",
    "mess_ups",
    "succeeded",
    "calls",
    "confesss",
    "stretchs",
    "sailed",
    "smiles",
    "exists",
    "prayed",
    "troubled",
    "interfered",
    "smelled",
    "objects",
    "replaces",
    "reached",
    "covered",
    "peeped",
    "avoids",
    "answers",
    "served",
    "reported",
    "remembered",
    "likes",
    "missed",
    "dragged",
    "hung",
    "presents",
    "files",
    "rinses",
    "dusted",
    "blinks",
    "gathered",
    "undresss",
    "warmed",
    "burned",
    "listens",
    "spoiled",
    "soothes",
    "informs",
    "grates",
    "identifys",
    "remembers",
    "washed",
    "jailed",
    "teases",
    "exercised",
    "loved",
    "manned",
    "admits",
    "films",
    "fancys",
    "laughs",
    "touched",
    "saves",
    "shaved",
    "snored",
    "begs",
    "plugs",
    "follows",
    "corrected",
    "wailed",
    "sighs",
    "exploded",
    "bounced",
    "robbed",
    "settled",
    "completed",
    "sips",
    "announces",
    "rhymes",
    "kisss",
    "separates",
    "radiates",
    "scolded",
    "headed",
    "subtracts",
    "parks",
    "disarms",
    "hopped",
    "deceived",
    "knitted",
    "scolds",
    "disappeared",
    "blots",
    "chops",
    "passed",
    "argued",
    "bangs",
    "detected",
    "fancied",
    "faced",
    "replys",
    "regrets",
    "ordered",
    "learned",
    "typed",
    "reflected",
    "pushs",
    "cheats",
    "bows",
    "brushs",
    "heaps",
    "folded",
    "informed",
    "closes",
    "disappears",
    "preferred",
    "tames",
    "explained",
    "battles",
    "scatters",
    "sacks",
    "bans",
    "attachs",
    "drains",
    "provided",
    "balances",
    "tours",
    "guards",
    "licked",
    "needs",
    "lasts",
    "pleased",
    "chases",
    "changed",
    "cheated",
    "knelt",
    "braked",
    "precedes",
    "boxs",
    "terrified",
    "poured",
    "considered",
    "offered",
    "balanced",
    "compared",
    "asked",
    "nests",
    "muddles",
    "examines",
    "grabs",
    "carved",
    "shocked",
    "checks",
    "printed",
    "analysed",
    "pricked",
    "occurred",
    "tried",
    "pinched",
    "belongs",
    "borrows",
    "moves",
    "shaves",
    "camps",
    "behaves",
    "dams",
    "raced",
    "dripped",
    "embarrasss",
    "ties",
    "hammers",
    "undressed",
    "messed_up",
    "increases",
    "bumped",
    "wanders",
    "stamps",
    "behaved",
    "admires",
    "contained",
    "blushs",
    "spots",
    "settles",
    "zipped",
    "consisted",
    "exercises",
    "lasted",
    "chews",
    "arrives",
    "whispers",
    "jumped",
    "flows",
    "soothed",
    "fried",
    "warms",
    "agrees",
    "sipped",
    "replaced",
    "packs",
    "adds",
    "plugged",
    "fastened",
    "rolled",
    "questions",
    "rained",
    "embarrassed",
    "knots",
    "measured",
    "concerned",
    "approved",
    "borrowed",
    "continues",
    "skied",
    "sparkled",
    "delayed",
    "locks",
    "twisted",
    "wastes",
    "supplied",
    "banged",
    "feared",
    "dreams",
    "concerns",
    "coiled",
    "sparked",
    "trembled",
    "crashs",
    "sounded",
    "marrys",
    "interested",
    "reduced",
    "levelled",
    "moaned",
    "hooks",
    "moved",
    "invited",
    "encourages",
    "mourns",
    "tempted",
    "listened",
    "complained",
    "guarantees",
    "completes",
    "traces",
    "whines",
    "pulls",
    "suited",
    "succeeds",
    "pumped",
    "hunts",
    "sheltered",
    "crosss",
    "unlocks",
    "pasted",
    "fixed",
    "bowed",
    "heats",
    "whirls",
    "guides",
    "depended",
    "whispered",
    "notes",
    "tumbles",
    "posts",
    "marched",
    "shaded",
    "pats",
    "cycles",
    "records",
    "prefers",
    "searched",
    "trusts",
    "lands",
    "ticked",
    "names",
    "retired",
    "polishs",
    "rhyme",
    "laughed",
    "mends",
    "delighted",
    "spoils",
    "scratchs",
    "unpacks",
    "followed",
    "jams",
    "warned",
    "advises",
    "fenced",
    "remains",
    "tickled",
    "snowed",
    "rains",
    "unlocked",
    "hugged",
    "trots",
    "confessed",
    "snatchs",
    "heated",
    "ruins",
    "enters",
    "flowers",
    "lied",
    "taps",
    "influenced",
    "brakes",
    "raises",
    "corrects",
    "cures",
    "rolls",
    "labels",
    "signs",
    "peeps",
    "collects",
    "promised",
    "pleases",
    "floods",
    "reigned",
    "returned",
    "frightened",
    "invented",
    "asks",
    "stirs",
    "vanished",
    "squeezed",
    "cycled",
    "squeezes",
    "visits",
    "claims",
    "glued",
    "extended",
    "separate",
    "phones",
    "detects",
    "rushed",
    "noted",
    "buzzs",
    "drained",
    "waves",
    "glowed",
    "competes",
    "chased",
    "bakes",
    "stained",
    "seals",
    "unfastens",
    "amused",
    "milks",
    "subtracted",
    "tired",
    "attempted",
    "suffered",
    "trapped",
    "backs",
    "protects",
    "depends",
    "wondered",
    "supposes",
    "joked",
    "traced",
    "confused",
    "hates",
    "united",
    "guided",
    "stamped",
    "starts",
    "sacked",
    "greases",
    "pined",
    "stirred",
    "jumps",
    "prepares",
    "reflects",
    "arrested",
    "itched",
    "argues",
    "shocks",
    "timed",
    "smokes",
    "screamed",
    "obeyed",
    "searchs",
    "branched",
    "guesss",
    "suffers",
    "drums",
    "turned",
    "destroyed",
    "pressed",
    "harmed",
    "possessed",
    "announced",
    "switched",
    "tips",
    "rubs",
    "loaded",
    "blushed",
    "whistled",
    "treats",
    "skis",
    "hovers",
    "connects",
    "claps",
    "jails",
    "deserts",
    "gathers",
    "licks",
    "blinked",
    "stroked",
    "communicated",
    "charges",
    "crushs",
    "drummed",
    "fetched",
    "talked",
    "hopes",
    "juggles",
    "nods",
    "decides",
    "considers",
    "coachs",
    "ruined",
    "unites",
    "places",
    "sniffed",
    "mixs",
    "notices",
    "tricked",
    "rushs",
    "meddled",
    "curves",
    "worked",
    "knocks",
    "guessed",
    "pastes",
    "kicked",
    "hums",
    "answered",
    "attempts",
    "prevents",
    "forces",
    "rejects",
    "surprised",
    "tumbled",
    "protected",
    "ignores",
    "multiplied",
    "injects",
    "drops",
    "owes",
    "repeats",
    "arrests",
    "dislikes",
    "concentrates",
    "patted",
    "appeared",
    "carves",
    "telephoned",
    "supports",
    "plans",
    "earns",
    "cracks",
    "commanded",
    "overflowed",
    "paused",
    "shades",
    "shares",
    "wonders",
    "includes",
    "wriggles",
    "repaired",
    "teased",
    "removes",
    "milked",
    "poked",
    "analyses",
    "reminded",
    "terrifys",
    "excuses",
    "repairs",
    "ticks",
    "folds",
    "thaws",
    "mourned",
    "mugs",
    "connected",
    "preserves",
    "soaks",
    "boasted",
    "invents",
    "used",
    "travels",
    "coughed",
    "manages",
    "cleans",
    "trembles",
    "appreciated",
    "yelled",
    "ignored",
    "sprayed",
    "blotted",
    "checked",
    "slips",
    "crashed",
    "practised",
    "paddled",
    "traded",
    "cheered",
    "tests",
    "smashed",
    "numbers",
    "smells",
    "fails",
    "causes",
    "handles",
    "developed",
    "called",
    "delights",
    "fires",
    "tugged",
    "welcomed",
    "wrestles",
    "types",
    "vanishs",
    "rotted",
    "frames",
    "contains",
    "replied",
    "owed",
    "loves",
    "permits",
    "allowed",
    "drowns",
    "reachs",
    "bathes",
    "boxed",
    "turns",
    "interrupts",
    "bats",
    "refuses",
    "disagrees",
    "satisfys",
    "fences",
    "planned",
    "charged",
    "rejected",
    "glows",
    "slaps",
    "wrecks",
    "named",
    "jokes",
    "delivered",
    "skips",
    "twists",
    "joins",
    "parked",
    "yells",
    "watered",
    "looks",
    "wriggled",
    "entertains",
    "happened",
    "shelters",
    "preserved",
    "plays",
    "melts",
    "added",
    "frightens",
    "spells",
    "produces",
    "tempts",
    "tugs",
    "arranges",
    "enjoyed",
    "heaped",
    "queues",
    "frys",
    "hoped",
    "unpacked",
    "pecks",
    "escaped",
    "begged",
    "jogged",
    "clips",
    "wobbled",
    "flowered",
    "trades",
    "fitted",
    "hangs",
    "claimed",
    "included",
    "kills",
    "rules",
    "avoided",
    "gazed",
    "deceives",
    "trips",
    "reproduced",
    "stretched",
    "allows",
    "delivers",
    "married",
    "straps",
    "weighed",
    "entered",
    "stuffed",
    "tripped",
    "impresss",
    "changes",
    "saved",
    "squeals",
    "permitted",
    "dropped",
    "picks",
    "supposed",
    "radiated",
    "alerted",
    "expand",
    "expands",
    "spotted",
    "slipped",
    "fools",
    "chokes",
    "towed",
    "managed",
    "spares",
    "pretends",
    "sins",
    "skipped",
    "knits",
    "gripped",
    "rescued",
    "warns",
    "scattered",
    "works",
    "levels",
    "expected",
    "closed",
    "switchs",
    "decayed",
    "sprouted",
    "traps",
    "snows",
    "waters",
    "beamed",
    "clapped",
    "bruises",
    "ruled",
    "tricks",
    "deserves",
    "danced",
    "competed",
    "troubles",
    "lightens",
    "examined",
    "carrys",
    "pumps",
    "practises",
    "produced",
    "hurrys",
    "increased",
    "regretted",
    "harassed",
    "cheers",
    "rocks",
    "formed",
    "intended",
    "times",
    "suggested",
    "scares",
    "wails",
    "clipped",
    "waits",
    "disagreed",
    "signals",
    "crawls",
    "groans",
    "doubles",
    "snores",
    "nodded",
    "whined",
    "escapes",
    "wished",
    "passs",
    "excused",
    "shops",
    "excites",
    "prays",
    "afforded",
    "judges",
    "fetchs",
    "requested",
    "clears",
    "stayed",
    "longed",
    "transported",
    "branchs",
    "punctured",
    "grips",
    "flashed",
    "whips",
    "shivers",
    "improved",
    "repeated",
    "whirled",
    "polished",
    "strengthened",
    "cares",
    "accepted",
    "tires",
    "buzzed",
    "offended",
    "shopped",
    "performed",
    "winked",
    "scrubbed",
    "releases",
    "realises",
    "scribbles",
    "joined",
    "trains",
    "challenged",
    "books",
    "interferes",
    "noticed",
    "jogs",
    "cleaned",
    "mended",
    "obtains",
    "thanked",
    "dances",
    "damaged",
    "offends",
    "telephones",
    "screws",
    "kicks",
    "introduced",
    "observed",
    "owned",
    "emptys",
    "unfastened",
    "packed",
    "squealed",
    "washs",
    "wraps",
    "flapped",
    "baked",
    "slapped",
    "knocked",
    "bounces",
    "stays",
    "soaked",
    "memorised",
    "admitted",
    "hammered",
    "supported",
    "phoned",
    "counts",
    "hummed",
    "sails",
    "memorises",
    "groaned",
    "alerts",
    "decorated",
    "challenges",
    "accepts",
    "posted",
    "pedals",
    "cracked",
    "beams",
    "combs",
    "pinchs",
    "wasted",
    "appreciates",
    "mates",
    "blinded",
    "explains",
    "dresss",
    "jammed",
    "presented",
    "learns",
    "fits",
    "fills",
    "boils",
    "multiplys",
    "damages",
    "bumps",
    "shivered",
    "breathes",
    "deserved",
    "harms",
    "drags",
    "disapproves",
    "wrecked",
    "plants",
    "tested",
    "greets",
    "punchs",
    "cared",
    "reduces",
    "signalled",
    "develops",
    "landed",
    "moored",
    "relaxed",
    "curled",
    "educated",
    "pricks",
    "burys",
    "backed",
    "discovers",
    "peels",
    "coughs",
    "peeled",
    "harasss",
    "decorates",
    "coached",
    "knotted",
    "camped",
    "irritated",
    "spelled",
    "sucked",
    "suggests",
    "wanted",
    "snatched",
    "welcomes",
    "mixed",
    "strips",
    "earned",
    "spilled",
    "paddles",
    "excited",
    "batted",
    "preachs",
    "covers",
    "remained",
    "arrived",
    "hooked",
    "calculates",
    "pretended",
    "hands",
    "booked",
    "doubted",
    "tasted",
    "disapproved",
    "describes",
    "listed",
    "sprays",
    "rots",
    "wants",
    "dried",
    "tied",
    "mans",
    "helps",
    "apologised",
    "surrounded",
    "scrapes",
    "discovered",
    "commands",
    "punishs",
    "bolts",
    "programmed",
    "programs",
    "curls",
    "choked",
    "suspected",
    "fastens",
    "moors",
    "weighs",
    "appears",
    "sneezed",
    "parts",
    "placed",
    "reminds",
    "irritates",
    "flowed",
    "calculated",
    "spared",
    "bared",
    "matched",
    "cleared",
    "crossed",
    "strapped",
    "rejoices",
    "annoys",
    "mugged",
    "pedalled",
    "spills",
    "haunted",
    "bombs",
    "injected",
    "educates",
    "continued",
    "coils",
    "fades",
    "matchs",
    "expects",
    "presss",
    "saws",
    "attracted",
    "bores",
    "scribbled",
    "deserted",
    "smashs",
    "encouraged",
    "mines",
    "tickles",
    "mated",
    "filmed",
    "stuffs",
    "played",
    "copys",
    "guaranteed",
    "shrugs",
    "untidied",
    "greased",
    "races",
    "hunted",
    "existed",
    "trotted",
];
